"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.AdRecord = void 0;
const uuid_1 = require("uuid");
const errors_1 = require("../utils/errors");
const db_1 = require("../utils/db");
class AdRecord {
    constructor(obj) {
        this.VALIDATION = (obj) => {
            if (obj.salaryMax > 9999999 || obj.salaryMin < 0 || obj.salaryMax < 0 || obj.salaryMin > 9999999) {
                throw new errors_1.ValidationError('the price cannot be less than 0 or more than 9999999');
            }
            if (!obj.creatorId || obj.creatorId.length !== 36) {
                throw new errors_1.ValidationError('creator id cannot be blank');
            }
            if (!obj.name || obj.name.length > 30) {
                throw new errors_1.ValidationError("Company name cannot be blank or exceed 30 characters");
            }
            if (!obj.address || obj.address.length > 100) {
                throw new errors_1.ValidationError("Address cannot be blank or exceed 100 characters");
            }
            if (!obj.title || obj.title.length > 50 || obj.title.length < 3) {
                throw new errors_1.ValidationError("Ad title cannot be blank or exceed 50 characters");
            }
            if (!obj.email || obj.email.length > 100) {
                throw new errors_1.ValidationError("E-mail cannot be blank or exceed 100 characters");
            }
            if (!obj.technology || obj.technology.length > 100) {
                throw new errors_1.ValidationError("Technology cannot be blank or exceed 100 characters");
            }
            if (!obj.description || obj.description.length > 1000) {
                throw new errors_1.ValidationError("Description cannot be blank or exceed 1000 characters");
            }
            if (typeof obj.lat !== 'number' || typeof obj.lon !== 'number') {
                throw new errors_1.ValidationError('The ad cannot be located.');
            }
        };
        this.VALIDATION(obj);
        this.address = obj.address;
        this.creatorId = obj.creatorId;
        this.description = obj.description;
        this.email = obj.email;
        this.image = obj.image;
        this.lat = obj.lat;
        this.lon = obj.lon;
        this.name = obj.name;
        this.salaryMax = obj.salaryMax;
        this.salaryMin = obj.salaryMin;
        this.technology = obj.technology;
        this.title = obj.title;
        this.id = obj.id;
    }
    static getOne(adId) {
        return __awaiter(this, void 0, void 0, function* () {
            const [results] = yield db_1.pool.execute("SELECT * FROM `ads` WHERE `id` = :id", {
                id: adId,
            });
            return results.length === 0 ? null : new AdRecord(results[0]);
        });
    }
    static getUserAds(userId) {
        return __awaiter(this, void 0, void 0, function* () {
            const [results] = yield db_1.pool.execute("SELECT * FROM `ads` WHERE `creatorId` = :userId", {
                userId,
            });
            return results.map(result => {
                const { address, creatorId, email, image, lat, lon, name, salaryMax, salaryMin, technology, title, id, date, } = result;
                return {
                    address,
                    creatorId,
                    email,
                    image,
                    lat,
                    lon,
                    name,
                    salaryMax,
                    salaryMin,
                    technology,
                    title,
                    id,
                    date,
                };
            });
        });
    }
    static findAll(name) {
        return __awaiter(this, void 0, void 0, function* () {
            const [results] = yield db_1.pool.execute("SELECT * FROM `ads` WHERE `name` LIKE :search OR `technology` LIKE :search OR `title` LIKE :search OR `address` LIKE :search ORDER BY `date` DESC", {
                search: `%${name}%`,
            });
            return results.map(result => {
                const { address, creatorId, email, image, lat, lon, name, salaryMax, salaryMin, technology, title, id, date, } = result;
                return {
                    address,
                    creatorId,
                    email,
                    image,
                    lat,
                    lon,
                    name,
                    salaryMax,
                    salaryMin,
                    technology,
                    title,
                    id,
                    date,
                };
            });
        });
    }
    insert() {
        return __awaiter(this, void 0, void 0, function* () {
            if (!this.id) {
                this.id = (0, uuid_1.v4)();
            }
            else {
                throw new Error('Cannot insert something that  is already inserted');
            }
            this.date = new Date();
            yield db_1.pool.execute("INSERT INTO `ads`(`id`, `description`, `email`, `technology`, `address`, `title`, `image`, `name`, `creatorId`, `salaryMin`, `salaryMax`, `lat`, `lon`, `date`) VALUES (:id,:description,:email,:technology,:address,:title,:image,:name,:creatorId,:salaryMin,:salaryMax,:lat,:lon,:date)", this);
        });
    }
    update() {
        return __awaiter(this, void 0, void 0, function* () {
            yield db_1.pool.execute("UPDATE `ads` SET `description` = :description,`email`=:email,`technology`= :technology,`address`=:address,`title`=:title,`name`=:name,`salaryMin`=:salaryMin,`salaryMax`=:salaryMax,`lat`=:lat,`lon`=:lon WHERE  `id`=:id", this);
        });
    }
    delete() {
        return __awaiter(this, void 0, void 0, function* () {
            yield db_1.pool.execute("DELETE FROM `ads` where `id` = :id", {
                id: this.id,
            });
        });
    }
}
exports.AdRecord = AdRecord;
//# sourceMappingURL=ad.record.js.map