"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.UserRecord = void 0;
const errors_1 = require("../utils/errors");
const bcrypt_1 = __importDefault(require("bcrypt"));
const jsonwebtoken_1 = __importDefault(require("jsonwebtoken"));
const db_1 = require("../utils/db");
const uuid_1 = require("uuid");
class UserRecord {
    constructor(obj) {
        this.token = null;
        this.VALIDATION = (obj) => {
            if (!obj.name || obj.name.length > 30) {
                throw new errors_1.ValidationError("Name cannot be blank or exceed 30 characters");
            }
            if (!obj.password || obj.password.length > 25 || obj.password.length < 6) {
                throw new errors_1.ValidationError("invalid password");
            }
            if (!obj.email || obj.email.length > 100) {
                throw new errors_1.ValidationError("Email cannot be blank or exceed 100 characters");
            }
        };
        this.email = obj.email;
        this.name = obj.name;
        this.id = obj.id;
        this.password = obj.password;
    }
    static getUser(uId) {
        return __awaiter(this, void 0, void 0, function* () {
            const [results] = yield db_1.pool.execute("SELECT * FROM `users` WHERE `id` = :id", {
                id: uId,
            });
            if (results.length === 0) {
                return null;
            }
            else {
                const { email, id, name, } = results[0];
                return { email, id, name };
            }
        });
    }
    singup() {
        return __awaiter(this, void 0, void 0, function* () {
            this.VALIDATION(this);
            if (!this.id) {
                this.id = (0, uuid_1.v4)();
            }
            else {
                throw new Error('Cannot insert something that  is already inserted');
            }
            const [existingUser] = yield db_1.pool.execute("SELECT * FROM `users` WHERE `email` = :email ", {
                email: this.email,
            });
            if (existingUser.length !== 0) {
                throw new errors_1.ValidationError("User exists already, please login instead");
            }
            try {
                this.password = yield bcrypt_1.default.hash(this.password, 12);
            }
            catch (e) {
                throw new errors_1.HttpError('Could not create user, please try again', 500);
            }
            try {
                yield db_1.pool.execute("INSERT INTO `users`(`id`,`name`, `email`, `password`) VALUES (:id,:name,:email,:password)", this);
            }
            catch (e) {
                throw new errors_1.HttpError('Creating a new user failed, please try again', 500);
            }
            try {
                this.token = jsonwebtoken_1.default.sign({
                    userId: this.id,
                    email: this.email,
                }, 'LASDFSAF@#ADSVS@#$@!@#$24', { expiresIn: '1h' });
            }
            catch (e) {
                throw new errors_1.HttpError('Creating a new user failed, please try again', 500);
            }
            return {
                email: this.email,
                name: this.name,
                id: this.id,
                token: this.token
            };
        });
    }
    login() {
        return __awaiter(this, void 0, void 0, function* () {
            const [user] = yield db_1.pool.execute("SELECT * FROM `users` WHERE `email` = :email ", {
                email: this.email,
            });
            if (user.length === 0) {
                throw new errors_1.ValidationError("Invalid credentials, could not login");
            }
            let isValidPassword;
            try {
                isValidPassword = yield bcrypt_1.default.compare(this.password, user[0].password);
            }
            catch (e) {
                throw new errors_1.HttpError('Could not log you in, please check your credentials and try again', 500);
            }
            if (!isValidPassword) {
                throw new errors_1.ValidationError("Invalid credentials, could not login");
            }
            const { email, name, id } = user[0];
            try {
                this.token = jsonwebtoken_1.default.sign({
                    userId: user[0].id,
                    email: user[0].email
                }, 'LASDFSAF@#ADSVS@#$@!@#$24', { expiresIn: '1h' });
            }
            catch (e) {
                throw new errors_1.HttpError('logging in failed, please try again', 500);
            }
            return { email, name, id, token: this.token };
        });
    }
}
exports.UserRecord = UserRecord;
//# sourceMappingURL=user.record.js.map