"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.adRouter = void 0;
const express_1 = require("express");
const ad_record_1 = require("../records/ad.record");
const errors_1 = require("../utils/errors");
const check_auth_1 = __importDefault(require("../utils/check-auth"));
const file_upload_1 = require("../utils/file-upload");
const path_1 = __importDefault(require("path"));
const promises_1 = require("fs/promises");
exports.adRouter = (0, express_1.Router)();
exports.adRouter.get('/', (req, res) => __awaiter(void 0, void 0, void 0, function* () {
    const ads = yield ad_record_1.AdRecord.findAll('');
    res.json({
        ads,
    });
}))
    .get('/:adId', (req, res) => __awaiter(void 0, void 0, void 0, function* () {
    const { adId } = req.params;
    const ad = yield ad_record_1.AdRecord.getOne(adId);
    if (ad === null) {
        throw new errors_1.HttpError('Could not find a ad for the provided id.', 404);
    }
    res.json({
        ad,
    });
}))
    .get('/search/:name', (req, res) => __awaiter(void 0, void 0, void 0, function* () {
    const { name } = req.params;
    const ads = yield ad_record_1.AdRecord.findAll(name);
    res.json({
        ads,
    });
}))
    .get('/user/:uId', (req, res) => __awaiter(void 0, void 0, void 0, function* () {
    const { uId } = req.params;
    const ads = yield ad_record_1.AdRecord.getUserAds(uId);
    res.json({
        ads,
    });
}))
    .use(check_auth_1.default)
    .post('/', file_upload_1.fileUpload.single('image'), (req, res) => __awaiter(void 0, void 0, void 0, function* () {
    const newAd = new ad_record_1.AdRecord(Object.assign(Object.assign({}, req.body), { lat: parseFloat(req.body.lat), lon: parseFloat(req.body.lon), salaryMin: parseFloat(req.body.salaryMin), salaryMax: parseFloat(req.body.salaryMax), image: req.file.path }));
    yield newAd.insert();
    if (newAd.creatorId !== req.userData.user.userId) {
        throw new errors_1.ValidationError('You are not allowed to Added this ad.');
    }
    res.status(201)
        .json({
        newAd,
    });
}))
    .patch('/:aId', (req, res) => __awaiter(void 0, void 0, void 0, function* () {
    const { aId } = req.params;
    const body = req.body;
    const ad = yield ad_record_1.AdRecord.getOne(aId);
    if (ad === null) {
        throw new errors_1.HttpError('Could not find a ad for the provided id.', 404);
    }
    if (ad.creatorId !== req.userData.user.userId) {
        throw new errors_1.ValidationError('You are not allowed to edit this ad.');
    }
    if (ad.id !== body.id) {
        throw new errors_1.HttpError('id must be provided.', 400);
    }
    const updateAd = new ad_record_1.AdRecord(Object.assign({}, body));
    yield updateAd.update();
    res.status(200).json({
        updateAd
    });
}))
    .delete('/:id', (req, res) => __awaiter(void 0, void 0, void 0, function* () {
    const ad = yield ad_record_1.AdRecord.getOne(req.params.id);
    if (!ad) {
        throw new errors_1.HttpError('No found ad.', 404);
    }
    if (ad.creatorId !== req.userData.user.userId) {
        throw new errors_1.ValidationError('You are not allowed to delete this ad.');
    }
    const pathImage = path_1.default.join(path_1.default.dirname('__dirname'), ad.image);
    yield ad.delete();
    yield (0, promises_1.rm)(pathImage);
    res.status(200).json({ message: "Delete ad successfully" });
}));
//# sourceMappingURL=ad.router.js.map