"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const user_record_1 = require("../records/user.record");
const defaultObj = {
    name: "Mateo Woj",
    email: "example@example.com",
    password: "123456",
};
test('UserRecord.getUser record returns data from database for one entry', () => __awaiter(void 0, void 0, void 0, function* () {
    const user = yield user_record_1.UserRecord.getUser('123456789012345678901234567890123456');
    expect(user).toBeDefined();
    expect(user.id).toBe('123456789012345678901234567890123456');
    expect(user.name).toBe('andrzej bialy');
    expect(user.email).toBe('andrzej@bialy.com');
    expect(user.password).not.toBeDefined();
}));
test('UserRecord.getOne return null from database for unexisting entry', () => __awaiter(void 0, void 0, void 0, function* () {
    const user = yield user_record_1.UserRecord.getUser('***');
    expect(user).toBeNull();
}));
test('UserRecord.singup returns new UUID', () => __awaiter(void 0, void 0, void 0, function* () {
    const user = new user_record_1.UserRecord(defaultObj);
    yield user.singup();
    expect(user.id).toBeDefined();
    expect(typeof user.id).toBe('string');
}));
test('UserRecord.singup inserts data to database', () => __awaiter(void 0, void 0, void 0, function* () {
    const user = new user_record_1.UserRecord(defaultObj);
    yield user.singup();
    const foundUser = yield user_record_1.UserRecord.getUser(user.id);
    expect(foundUser).toBeDefined();
    expect(foundUser.id).toEqual(user.id);
}));
test('UserRecord.login returns id,email,name and password not defined', () => __awaiter(void 0, void 0, void 0, function* () {
    const user = new user_record_1.UserRecord({
        email: "example@example.com",
        password: "123456",
        name: "login"
    });
    const login = yield user.login();
    expect(login.id).toBeDefined();
    expect(login.email).toBe("example@example.com");
    expect(login.name).toBeDefined();
}));
test('UserRecord.login validate email', () => __awaiter(void 0, void 0, void 0, function* () {
    const user = new user_record_1.UserRecord({
        email: "esfsfe@examsdfsafple.com",
        password: "123456",
        name: "login"
    });
    yield expect(() => __awaiter(void 0, void 0, void 0, function* () { return yield user.login(); })).rejects.toThrow("Invalid credentials, could not login");
}));
test('UserRecord.login validate password', () => __awaiter(void 0, void 0, void 0, function* () {
    const user = new user_record_1.UserRecord({
        email: "esfsfe@examsdfsafple.com",
        password: "asdfgasdf",
        name: "login"
    });
    yield expect(() => __awaiter(void 0, void 0, void 0, function* () { return yield user.login(); })).rejects.toThrow("Invalid credentials, could not login");
}));
//# sourceMappingURL=user.test.js.map